FFRRouteDefinition class

Constructors

FFRRouteDefinition({required String id, required String path, required FFRRouteWidgetBuilder builder, FFRRouteType routeType = FFRRouteType.fullPage, Map<String, String> pathParams = const {}, Map<String, dynamic> queryParams = const {}, FFROpenFlow openFlow = FFROpenFlow.postLogin, String title = '', String description = ''})
const

Properties

builder FFRRouteWidgetBuilder
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
openFlow FFROpenFlow
final
path String
final
pathParams Map<String, String>
Key: param name (e.g., 'uid'), Value: Regex pattern string (e.g., r'0-9+')
final
queryParams Map<String, dynamic>
final
routeType FFRRouteType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited