FFRRouteMatch class
Constructors
-
FFRRouteMatch({required String originalUrl, required FFRRouteDefinition route, Map<
String, String> pathParams = const {}, Map<String, dynamic> queryParams = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalUrl → String
-
final
-
pathParams
→ Map<
String, String> -
final
-
queryParams
→ Map<
String, dynamic> -
final
- route → FFRRouteDefinition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited